pub struct WebsocketServer { /* private fields */ }Expand description
The WebSocket server itself
Implementations
Sourceimpl WebsocketServer
impl WebsocketServer
Sourcepub fn new(
ip_address: String,
port: String,
cert_path: Option<String>,
key_path: Option<String>,
) -> Self
pub fn new( ip_address: String, port: String, cert_path: Option<String>, key_path: Option<String>, ) -> Self
Create a new WebSocket server instance
Sourcepub fn get_message_sender(&self) -> Sender<(String, WebSocketMessage)>
pub fn get_message_sender(&self) -> Sender<(String, WebSocketMessage)>
Get a clone of the message sender for sending messages to clients
Sourcepub fn take_message_receiver(
&self,
) -> Option<Receiver<(String, WebSocketMessage)>>
pub fn take_message_receiver( &self, ) -> Option<Receiver<(String, WebSocketMessage)>>
Take the message receiver to process incoming messages
Sourcepub async fn start(&self) -> Receiver<(String, WebSocketMessage)>
pub async fn start(&self) -> Receiver<(String, WebSocketMessage)>
Start the WebSocket server and return the message receiver for processing incoming messages
Sourcepub async fn send_to_client(
&self,
client_id: String,
message: WebSocketMessage,
) -> Result<(), String>
pub async fn send_to_client( &self, client_id: String, message: WebSocketMessage, ) -> Result<(), String>
Send a message to a specific client
Sourcepub async fn broadcast(&self, message: WebSocketMessage) -> Result<(), String>
pub async fn broadcast(&self, message: WebSocketMessage) -> Result<(), String>
Send a message to all connected clients
Sourcepub async fn get_clients(&self) -> Vec<String>
pub async fn get_clients(&self) -> Vec<String>
Get a list of all connected client IDs